@@ -9,7 +9,11 @@ from __future__ import print_function
 import IMP.atom
 import IMP.rmf
 import RMF
-m = IMP.kernel.Model()
+import sys
+
+IMP.setup_from_argv(sys.argv, "link")
+
+m = IMP.Model()
 
 # Create a new IMP.atom.Hierarchy from the contents of the pdb file
 h = IMP.atom.read_pdb(IMP.rmf.get_example_path("simple.pdb"), m)
